@@ -29,6 +29,7 @@ class MGMT_WEBAPP:
     EMULATIONS_PAGE_RESOURCE = "emulations-page"
     IMAGES_PAGE_RESOURCE = "images-page"
     DOWNLOADS_PAGE_RESOURCE = "downloads-page"
+    SERVER_CLUSTER_PAGE_RESOURCE = "server-cluster-page"
     JOBS_PAGE_RESOURCE = "jobs-page"
     MONITORING_PAGE_RESOURCE = "monitoring-page"
     POLICIES_PAGE_RESOURCE = "policies-page"
@@ -45,6 +46,7 @@ class MGMT_WEBAPP:
     TRACES_PAGE_RESOURCE = "traces-page"
     TRAINING_PAGE_RESOURCE = "training-page"
     CADVISOR_RESOURCE = "cadvisor"
+    PGADMIN_RESOURCE = "pgadmin"
     GRAFANA_RESOURCE = "grafana"
     NODE_EXPORTER_RESOURCE = "node-exporter"
     PROMETHEUS_RESOURCE = "prometheus"
@@ -115,6 +117,7 @@ class MGMT_WEBAPP:
     USERS_RESOURCE = "users"
     LOGS_RESOURCE = "logs"
     CONFIG_RESOURCE = "config"
+    SERVER_CLUSTER_RESOURCE = "server-cluster"
     VERSION_RESOURCE = "version"
     DQN_POLICIES_RESOURCE = "dqn-policies"
     FNN_W_SOFTMAX_POLICIES_RESOURCE = "fnn-w-softmax-policies"
