@@ -2,7 +2,7 @@ from flask import Flask
 from . import socketio
 import csle_common.constants.constants as constants
 from csle_common.logging.log import Logger
-from csle_common.dao.emulation_config.config import Config
+from csle_common.util.cluster_util import ClusterUtil
 from csle_rest_api.pages.emulations.routes import get_emulations_page_bp
 from csle_rest_api.pages.simulations.routes import get_simulations_page_bp
 from csle_rest_api.pages.monitoring.routes import get_monitoring_page_bp
@@ -25,9 +25,11 @@ from csle_rest_api.pages.host_terminal.routes import get_host_terminal_page_bp
 from csle_rest_api.pages.container_terminal.routes import get_container_terminal_page_bp
 from csle_rest_api.pages.system_admin.routes import get_system_admin_page_bp
 from csle_rest_api.pages.logs_admin.routes import get_logs_admin_page_bp
+from csle_rest_api.pages.server_cluster.routes import get_server_cluster_page_bp
 from csle_rest_api.resources.node_exporter.routes import node_exporter_bp
 from csle_rest_api.resources.prometheus.routes import prometheus_bp
 from csle_rest_api.resources.cadvisor.routes import cadvisor_bp
+from csle_rest_api.resources.pgadmin.routes import pgadmin_bp
 from csle_rest_api.resources.grafana.routes import grafana_bp
 from csle_rest_api.resources.emulations.routes import emulations_bp
 from csle_rest_api.resources.emulation_executions.routes import emulation_executions_bp
@@ -59,6 +61,7 @@ from csle_rest_api.resources.traces_datasets.routes import traces_datasets_bp
 from csle_rest_api.resources.statistics_datasets.routes import statistics_datasets_bp
 from csle_rest_api.resources.users.routes import users_bp
 from csle_rest_api.resources.config.routes import config_bp
+from csle_rest_api.resources.server_cluster.routes import server_cluster_bp
 from csle_rest_api.resources.version.routes import version_bp
 from csle_rest_api.resources.logs.routes import logs_bp
 from csle_rest_api.web_sockets.host_terminal.host_terminal import get_host_terminal_bp
@@ -102,8 +105,13 @@ def create_app(static_folder: str):
     app.register_blueprint(get_downloads_page_bp(static_folder=f"../../{static_folder}"),
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.DOWNLOADS_PAGE_RESOURCE}")
+    app.register_blueprint(get_server_cluster_page_bp(static_folder=f"../../{static_folder}"),
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
+                                      f"{api_constants.MGMT_WEBAPP.SERVER_CLUSTER_PAGE_RESOURCE}")
     app.register_blueprint(cadvisor_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.CADVISOR_RESOURCE}")
+    app.register_blueprint(pgadmin_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.PGADMIN_RESOURCE}")
     app.register_blueprint(grafana_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}{api_constants.MGMT_WEBAPP.GRAFANA_RESOURCE}")
     app.register_blueprint(get_images_page_bp(static_folder=f"../../{static_folder}"),
@@ -239,6 +247,9 @@ def create_app(static_folder: str):
     app.register_blueprint(config_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.CONFIG_RESOURCE}")
+    app.register_blueprint(server_cluster_bp,
+                           url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
+                                      f"{api_constants.MGMT_WEBAPP.SERVER_CLUSTER_RESOURCE}")
     app.register_blueprint(version_bp,
                            url_prefix=f"{constants.COMMANDS.SLASH_DELIM}"
                                       f"{api_constants.MGMT_WEBAPP.VERSION_RESOURCE}")
@@ -281,7 +292,7 @@ def start_server(static_folder: str, port: int = 7777, num_threads: int = 100, h
     # run(f"gunicorn -b {host}:{port} 'csle_rest_api.rest_api:create_app() --workers 4 --threads
     # {num_threads}'".split(' '))
     # gunicorn -b 0.0.0.0:5000 --workers 4 --threads num_threads module:app
-    Config.set_config_parameters_from_config_file()
+    ClusterUtil.set_config_parameters_from_config_file()
     Logger.__call__().get_logger().info(f"Starting web server, listening on port: {port}")
     app = create_app(static_folder=static_folder)
     socketio.run(app, debug=False, port=port, host=host)
